==> react-source-render-1.0.2.tgz: package/README.md <==
<!-- Logo -->
<p align="center">
  <a href="https://layershifter.github.io/react-source-render/">
    <img height="128" width="128" src="https://github.com/layershifter/react-source-render/raw/master/public/logo-teal.png">
  </a>
</p>

<!-- Name -->
<h1 align="center">
  <a href="https://layershifter.github.io/react-source-render/">React Source Render</a>
</h1>

<!-- Badges -->
<p align="center">
  <a href="https://travis-ci.com/layershifter/react-source-render">
    <img alt="Travis CI" src="https://img.shields.io/travis/project/layershifter/react-source-render/master.svg?style=flat-square" />
  </a>
  <a href="https://codecov.io/gh/layershifter/react-source-render">
    <img alt="Codecov" src="https://img.shields.io/codecov/c/github/layershifter/react-source-render/master.svg?style=flat-square" />
  </a>
  <a href="https://david-dm.org/layershifter/react-source-render">
    <img alt="David" src="https://img.shields.io/david/layershifter/react-source-render.svg?style=flat-square" />
  </a>
  <a href="https://www.npmjs.com/package/react-source-render">
    <img alt="npm" src="https://img.shields.io/npm/v/react-source-render.svg?style=flat-square" />
  </a>
</p>


# Solved problem
      
This component was initially designed to replace the [existing render](https://github.com/Semantic-Org/Semantic-UI-React/blob/e786724c73a6446fc5e86828ba446c18d4a9baab/docs/src/components/ComponentDoc/ComponentExample/renderExampleSourceCode.js) playground in Semantic UI React docs. React Source Render is designed to be used with [Babel Standalone](https://babeljs.io/docs/en/next/babel-standalone.html). The component consists from the parts:

- rendering component
- Babel plugin to transform imports and resoolve them
- Babel plugin to transform code to IIFE

# Quick start

```bash
$ yarn add react-source-render
# or
$ npm install react-source-render --save
```

# More

[Explore docs](https://layershifter.github.io/react-source-render/) for live demo.

==> react-source-render-1.1.2.tgz: package/README.md <==
<!-- Logo -->
<p align="center">
  <a href="https://layershifter.github.io/react-source-render/">
    <img height="128" width="128" src="https://github.com/layershifter/react-source-render/raw/master/public/logo-teal.png">
  </a>
</p>

<!-- Name -->
<h1 align="center">
  <a href="https://layershifter.github.io/react-source-render/">React Source Render</a>
</h1>

<!-- Badges -->
<p align="center">
  <a href="https://www.npmjs.com/package/react-source-render">
    <img alt="npm" src="https://img.shields.io/npm/v/react-source-render.svg?style=flat-square" />
  </a>
  <a href="https://travis-ci.com/layershifter/react-source-render">
    <img alt="Travis CI" src="https://img.shields.io/travis/com/layershifter/react-source-render/master.svg?style=flat-square" />
  </a>
  <a href="https://codecov.io/gh/layershifter/react-source-render">
    <img alt="Codecov" src="https://img.shields.io/codecov/c/github/layershifter/react-source-render/master.svg?style=flat-square" />
  </a>
  <a href="https://david-dm.org/layershifter/react-source-render">
    <img alt="David" src="https://img.shields.io/david/layershifter/react-source-render.svg?style=flat-square" />
  </a>
 
  <img src="http://img.badgesize.io/https://unpkg.com/react-source-render/lib/cjs/react-source-render.production.js?compression=gzip&label=gzip%20size&style=flat-square">
  <img src="http://img.badgesize.io/https://unpkg.com/react-source-render/lib/cjs/react-source-render.production.js?label=size&style=flat-square">
</p>


# Solved problem
      
This component was initially designed to replace the [existing render](https://github.com/Semantic-Org/Semantic-UI-React/blob/e786724c73a6446fc5e86828ba446c18d4a9baab/docs/src/components/ComponentDoc/ComponentExample/renderExampleSourceCode.js) playground in Semantic UI React docs. React Source Render is designed to be used with [Babel Standalone](https://babeljs.io/docs/en/next/babel-standalone.html). The component consists from the parts:

- rendering component
- Babel plugin to transform imports and resoolve them
- Babel plugin to transform code to IIFE

# Quick start

```bash
$ yarn add react-source-render
# or
$ npm install react-source-render --save
```

# More

[Explore docs](https://layershifter.github.io/react-source-render/) for live demo.
